"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HealthCheckHealthCheckTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___HealthCheckHealthCheckTag = HealthCheckHealthCheckTag

@typing_extensions.final
class HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HealthCheckConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_CONFIG_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def health_check_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def health_check_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheckHealthCheckTag]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        health_check_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        health_check_tags: collections.abc.Iterable[global___HealthCheckHealthCheckTag] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_config", b"health_check_config", "health_check_tags", b"health_check_tags", "resource_info", b"resource_info"]) -> None: ...

global___HealthCheck = HealthCheck

@typing_extensions.final
class Route53(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_FIELD_NUMBER: builtins.int
    RECORD_SET_FIELD_NUMBER: builtins.int
    RECORD_SET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def health_check(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HealthCheck]: ...
    @property
    def hosted_zone(self) -> global___HostedZone: ...
    @property
    def record_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordSet]: ...
    @property
    def record_set_group(self) -> global___RecordSetGroup: ...
    def __init__(
        self,
        *,
        health_check: collections.abc.Iterable[global___HealthCheck] | None = ...,
        hosted_zone: global___HostedZone | None = ...,
        record_set: collections.abc.Iterable[global___RecordSet] | None = ...,
        record_set_group: global___RecordSetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosted_zone", b"hosted_zone", "record_set_group", b"record_set_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check", b"health_check", "hosted_zone", b"hosted_zone", "record_set", b"record_set", "record_set_group", b"record_set_group"]) -> None: ...

global___Route53 = Route53

@typing_extensions.final
class HostedZoneHostedZoneConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comment: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comment: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "resource_info", b"resource_info"]) -> None: ...

global___HostedZoneHostedZoneConfig = HostedZoneHostedZoneConfig

@typing_extensions.final
class HostedZoneHostedZoneTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___HostedZoneHostedZoneTag = HostedZoneHostedZoneTag

@typing_extensions.final
class HostedZoneQueryLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLOUD_WATCH_LOGS_LOG_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cloud_watch_logs_log_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cloud_watch_logs_log_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_watch_logs_log_group_arn", b"cloud_watch_logs_log_group_arn", "resource_info", b"resource_info"]) -> None: ...

global___HostedZoneQueryLoggingConfig = HostedZoneQueryLoggingConfig

@typing_extensions.final
class HostedZoneVPC(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    VPC_REGION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    vpc_id: builtins.str
    vpc_region: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        vpc_id: builtins.str = ...,
        vpc_region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "vpc_id", b"vpc_id", "vpc_region", b"vpc_region"]) -> None: ...

global___HostedZoneVPC = HostedZoneVPC

@typing_extensions.final
class HostedZone(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_CONFIG_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    QUERY_LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    VPCS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def hosted_zone_config(self) -> global___HostedZoneHostedZoneConfig: ...
    @property
    def hosted_zone_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedZoneHostedZoneTag]: ...
    name: builtins.str
    @property
    def query_logging_config(self) -> global___HostedZoneQueryLoggingConfig: ...
    @property
    def vpcs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostedZoneVPC]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        hosted_zone_config: global___HostedZoneHostedZoneConfig | None = ...,
        hosted_zone_tags: collections.abc.Iterable[global___HostedZoneHostedZoneTag] | None = ...,
        name: builtins.str = ...,
        query_logging_config: global___HostedZoneQueryLoggingConfig | None = ...,
        vpcs: collections.abc.Iterable[global___HostedZoneVPC] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosted_zone_config", b"hosted_zone_config", "query_logging_config", b"query_logging_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosted_zone_config", b"hosted_zone_config", "hosted_zone_tags", b"hosted_zone_tags", "name", b"name", "query_logging_config", b"query_logging_config", "resource_info", b"resource_info", "vpcs", b"vpcs"]) -> None: ...

global___HostedZone = HostedZone

@typing_extensions.final
class RecordSetAliasTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DNS_NAME_FIELD_NUMBER: builtins.int
    EVALUATE_TARGET_HEALTH_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dns_name: builtins.str
    evaluate_target_health: builtins.bool
    hosted_zone_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dns_name: builtins.str = ...,
        evaluate_target_health: builtins.bool = ...,
        hosted_zone_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_name", b"dns_name", "evaluate_target_health", b"evaluate_target_health", "hosted_zone_id", b"hosted_zone_id", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetAliasTarget = RecordSetAliasTarget

@typing_extensions.final
class RecordSetGeoLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTINENT_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    SUBDIVISION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    continent_code: builtins.str
    country_code: builtins.str
    subdivision_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        continent_code: builtins.str = ...,
        country_code: builtins.str = ...,
        subdivision_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continent_code", b"continent_code", "country_code", b"country_code", "resource_info", b"resource_info", "subdivision_code", b"subdivision_code"]) -> None: ...

global___RecordSetGeoLocation = RecordSetGeoLocation

@typing_extensions.final
class RecordSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALIAS_TARGET_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    FAILOVER_FIELD_NUMBER: builtins.int
    GEO_LOCATION_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    MULTI_VALUE_ANSWER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_RECORDS_FIELD_NUMBER: builtins.int
    SET_IDENTIFIER_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alias_target(self) -> global___RecordSetAliasTarget: ...
    comment: builtins.str
    failover: builtins.str
    @property
    def geo_location(self) -> global___RecordSetGeoLocation: ...
    health_check_id: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    multi_value_answer: builtins.bool
    name: builtins.str
    region: builtins.str
    @property
    def resource_records(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    set_identifier: builtins.str
    ttl: builtins.str
    type: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alias_target: global___RecordSetAliasTarget | None = ...,
        comment: builtins.str = ...,
        failover: builtins.str = ...,
        geo_location: global___RecordSetGeoLocation | None = ...,
        health_check_id: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        multi_value_answer: builtins.bool = ...,
        name: builtins.str = ...,
        region: builtins.str = ...,
        resource_records: collections.abc.Iterable[builtins.str] | None = ...,
        set_identifier: builtins.str = ...,
        ttl: builtins.str = ...,
        type: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "geo_location", b"geo_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "comment", b"comment", "failover", b"failover", "geo_location", b"geo_location", "health_check_id", b"health_check_id", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "multi_value_answer", b"multi_value_answer", "name", b"name", "region", b"region", "resource_info", b"resource_info", "resource_records", b"resource_records", "set_identifier", b"set_identifier", "ttl", b"ttl", "type", b"type", "weight", b"weight"]) -> None: ...

global___RecordSet = RecordSet

@typing_extensions.final
class RecordSetGroupAliasTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DNS_NAME_FIELD_NUMBER: builtins.int
    EVALUATE_TARGET_HEALTH_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dns_name: builtins.str
    evaluate_target_health: builtins.bool
    hosted_zone_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dns_name: builtins.str = ...,
        evaluate_target_health: builtins.bool = ...,
        hosted_zone_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_name", b"dns_name", "evaluate_target_health", b"evaluate_target_health", "hosted_zone_id", b"hosted_zone_id", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetGroupAliasTarget = RecordSetGroupAliasTarget

@typing_extensions.final
class RecordSetGroupGeoLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONTINENT_CODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    SUBDIVISION_CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    continent_code: builtins.str
    country_code: builtins.str
    subdivision_code: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        continent_code: builtins.str = ...,
        country_code: builtins.str = ...,
        subdivision_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continent_code", b"continent_code", "country_code", b"country_code", "resource_info", b"resource_info", "subdivision_code", b"subdivision_code"]) -> None: ...

global___RecordSetGroupGeoLocation = RecordSetGroupGeoLocation

@typing_extensions.final
class RecordSetGroupRecordSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALIAS_TARGET_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    FAILOVER_FIELD_NUMBER: builtins.int
    GEO_LOCATION_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    MULTI_VALUE_ANSWER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_RECORDS_FIELD_NUMBER: builtins.int
    SET_IDENTIFIER_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alias_target(self) -> global___RecordSetGroupAliasTarget: ...
    comment: builtins.str
    failover: builtins.str
    @property
    def geo_location(self) -> global___RecordSetGroupGeoLocation: ...
    health_check_id: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    multi_value_answer: builtins.bool
    name: builtins.str
    region: builtins.str
    @property
    def resource_records(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    set_identifier: builtins.str
    ttl: builtins.str
    weight: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alias_target: global___RecordSetGroupAliasTarget | None = ...,
        comment: builtins.str = ...,
        failover: builtins.str = ...,
        geo_location: global___RecordSetGroupGeoLocation | None = ...,
        health_check_id: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        multi_value_answer: builtins.bool = ...,
        name: builtins.str = ...,
        region: builtins.str = ...,
        resource_records: collections.abc.Iterable[builtins.str] | None = ...,
        set_identifier: builtins.str = ...,
        ttl: builtins.str = ...,
        weight: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "geo_location", b"geo_location", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias_target", b"alias_target", "comment", b"comment", "failover", b"failover", "geo_location", b"geo_location", "health_check_id", b"health_check_id", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "multi_value_answer", b"multi_value_answer", "name", b"name", "region", b"region", "resource_info", b"resource_info", "resource_records", b"resource_records", "set_identifier", b"set_identifier", "ttl", b"ttl", "weight", b"weight"]) -> None: ...

global___RecordSetGroupRecordSet = RecordSetGroupRecordSet

@typing_extensions.final
class RecordSetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMENT_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_ID_FIELD_NUMBER: builtins.int
    HOSTED_ZONE_NAME_FIELD_NUMBER: builtins.int
    RECORD_SETS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comment: builtins.str
    hosted_zone_id: builtins.str
    hosted_zone_name: builtins.str
    @property
    def record_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RecordSetGroupRecordSet]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comment: builtins.str = ...,
        hosted_zone_id: builtins.str = ...,
        hosted_zone_name: builtins.str = ...,
        record_sets: collections.abc.Iterable[global___RecordSetGroupRecordSet] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comment", b"comment", "hosted_zone_id", b"hosted_zone_id", "hosted_zone_name", b"hosted_zone_name", "record_sets", b"record_sets", "resource_info", b"resource_info"]) -> None: ...

global___RecordSetGroup = RecordSetGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgcp/gcp_compute_route.proto\x12\x1doak9.tython.gcp.compute_route\x1a\x13shared/shared.proto\"7\n\x15\x43omputeRouteXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xde\x03\n\x0c\x43omputeRoute\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\ndest_range\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x18\n\x10next_hop_gateway\x18\x06 \x01(\t\x12\x14\n\x0cnext_hop_ilb\x18\x07 \x01(\t\x12\x19\n\x11next_hop_instance\x18\x08 \x01(\t\x12\x1e\n\x16next_hop_instance_zone\x18\t \x01(\t\x12\x13\n\x0bnext_hop_ip\x18\n \x01(\t\x12\x18\n\x10next_hop_network\x18\x0b \x01(\t\x12\x1b\n\x13next_hop_vpn_tunnel\x18\x0c \x01(\t\x12\x10\n\x08priority\x18\r \x01(\x01\x12\x0f\n\x07project\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12\x46\n\x08timeouts\x18\x11 \x01(\x0b\x32\x34.oak9.tython.gcp.compute_route.ComputeRouteXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_route_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEROUTEXTIMEOUTS._serialized_start=83
  _COMPUTEROUTEXTIMEOUTS._serialized_end=138
  _COMPUTEROUTE._serialized_start=141
  _COMPUTEROUTE._serialized_end=619
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_tpu.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_tpu.proto\x12\x13oak9.tython.gcp.tpu\x1a\x13shared/shared.proto\"/\n\x18TpuNodeXSchedulingConfig\x12\x13\n\x0bpreemptible\x18\x01 \x01(\x08\"B\n\x10TpuNodeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x98\x05\n\x07TpuNode\x12\x18\n\x10\x61\x63\x63\x65lerator_type\x18\x01 \x01(\t\x12\x12\n\ncidr_block\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x38\n\x06labels\x18\x05 \x03(\x0b\x32(.oak9.tython.gcp.tpu.TpuNode.LabelsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12M\n\x11network_endpoints\x18\x08 \x03(\x0b\x32\x32.oak9.tython.gcp.tpu.TpuNode.NetworkEndpointsEntry\x12\x0f\n\x07project\x18\t \x01(\t\x12\x17\n\x0fservice_account\x18\n \x01(\t\x12\x1a\n\x12tensorflow_version\x18\x0b \x01(\t\x12\x1e\n\x16use_service_networking\x18\x0c \x01(\x08\x12\x0c\n\x04zone\x18\r \x01(\t\x12H\n\x11scheduling_config\x18\x0e \x01(\x0b\x32-.oak9.tython.gcp.tpu.TpuNodeXSchedulingConfig\x12\x37\n\x08timeouts\x18\x0f \x01(\x0b\x32%.oak9.tython.gcp.tpu.TpuNodeXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15NetworkEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_tpu_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TPUNODE_LABELSENTRY._options = None
  _TPUNODE_LABELSENTRY._serialized_options = b'8\001'
  _TPUNODE_NETWORKENDPOINTSENTRY._options = None
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_options = b'8\001'
  _TPUNODEXSCHEDULINGCONFIG._serialized_start=63
  _TPUNODEXSCHEDULINGCONFIG._serialized_end=110
  _TPUNODEXTIMEOUTS._serialized_start=112
  _TPUNODEXTIMEOUTS._serialized_end=178
  _TPUNODE._serialized_start=181
  _TPUNODE._serialized_end=845
  _TPUNODE_LABELSENTRY._serialized_start=743
  _TPUNODE_LABELSENTRY._serialized_end=788
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_start=790
  _TPUNODE_NETWORKENDPOINTSENTRY._serialized_end=845
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_lakeformation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61ws/aws_lakeformation.proto\x12\x1doak9.tython.aws.lakeformation\x1a\x13shared/shared.proto\"Q\n\x16\x44\x61taLakeSettingsAdmins\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x10\x44\x61taLakeSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x06\x61\x64mins\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.lakeformation.DataLakeSettingsAdmins\"\xca\x02\n\rLakeFormation\x12K\n\x12\x64\x61ta_lake_settings\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.lakeformation.DataLakeSettings\x12?\n\x0bpermissions\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.lakeformation.Permissions\x12\x39\n\x08resource\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.lakeformation.Resource\x12p\n&data_lake_settings_data_lake_principal\x18\x04 \x03(\x0b\x32@.oak9.tython.aws.lakeformation.DataLakeSettingsDataLakePrincipal\"\x7f\n\x1cPermissionsDataLakePrincipal\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x64\x61ta_lake_principal_identifier\x18\x02 \x01(\t\"S\n\x18PermissionsTableWildcard\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdd\x01\n\x18PermissionsTableResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12O\n\x0etable_wildcard\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.lakeformation.PermissionsTableWildcard\x12\x0c\n\x04name\x18\x05 \x01(\t\"x\n\x1bPermissionsDatabaseResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x83\x01\n\x1fPermissionsDataLocationResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bs3_resource\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\"s\n\x19PermissionsColumnWildcard\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x65xcluded_column_names\x18\x02 \x03(\t\"\x80\x02\n#PermissionsTableWithColumnsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63olumn_names\x18\x02 \x03(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12Q\n\x0f\x63olumn_wildcard\x18\x06 \x01(\x0b\x32\x38.oak9.tython.aws.lakeformation.PermissionsColumnWildcard\"\xbf\x03\n\x13PermissionsResource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0etable_resource\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.lakeformation.PermissionsTableResource\x12U\n\x11\x64\x61tabase_resource\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.lakeformation.PermissionsDatabaseResource\x12^\n\x16\x64\x61ta_location_resource\x18\x04 \x01(\x0b\x32>.oak9.tython.aws.lakeformation.PermissionsDataLocationResource\x12g\n\x1btable_with_columns_resource\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.lakeformation.PermissionsTableWithColumnsResource\"\xa2\x02\n\x0bPermissions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x13\x64\x61ta_lake_principal\x18\x02 \x01(\x0b\x32;.oak9.tython.aws.lakeformation.PermissionsDataLakePrincipal\x12\x44\n\x08resource\x18\x03 \x01(\x0b\x32\x32.oak9.tython.aws.lakeformation.PermissionsResource\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\x12%\n\x1dpermissions_with_grant_option\x18\x05 \x03(\t\"\x8c\x01\n\x08Resource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x1f\n\x17use_service_linked_role\x18\x03 \x01(\x08\x12\x10\n\x08role_arn\x18\x04 \x01(\t\"\x84\x01\n!DataLakeSettingsDataLakePrincipal\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x64\x61ta_lake_principal_identifier\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_lakeformation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATALAKESETTINGSADMINS._serialized_start=83
  _DATALAKESETTINGSADMINS._serialized_end=164
  _DATALAKESETTINGS._serialized_start=167
  _DATALAKESETTINGS._serialized_end=313
  _LAKEFORMATION._serialized_start=316
  _LAKEFORMATION._serialized_end=646
  _PERMISSIONSDATALAKEPRINCIPAL._serialized_start=648
  _PERMISSIONSDATALAKEPRINCIPAL._serialized_end=775
  _PERMISSIONSTABLEWILDCARD._serialized_start=777
  _PERMISSIONSTABLEWILDCARD._serialized_end=860
  _PERMISSIONSTABLERESOURCE._serialized_start=863
  _PERMISSIONSTABLERESOURCE._serialized_end=1084
  _PERMISSIONSDATABASERESOURCE._serialized_start=1086
  _PERMISSIONSDATABASERESOURCE._serialized_end=1206
  _PERMISSIONSDATALOCATIONRESOURCE._serialized_start=1209
  _PERMISSIONSDATALOCATIONRESOURCE._serialized_end=1340
  _PERMISSIONSCOLUMNWILDCARD._serialized_start=1342
  _PERMISSIONSCOLUMNWILDCARD._serialized_end=1457
  _PERMISSIONSTABLEWITHCOLUMNSRESOURCE._serialized_start=1460
  _PERMISSIONSTABLEWITHCOLUMNSRESOURCE._serialized_end=1716
  _PERMISSIONSRESOURCE._serialized_start=1719
  _PERMISSIONSRESOURCE._serialized_end=2166
  _PERMISSIONS._serialized_start=2169
  _PERMISSIONS._serialized_end=2459
  _RESOURCE._serialized_start=2462
  _RESOURCE._serialized_end=2602
  _DATALAKESETTINGSDATALAKEPRINCIPAL._serialized_start=2605
  _DATALAKESETTINGSDATALAKEPRINCIPAL._serialized_end=2737
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BoundObjectReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    name: builtins.str
    uid: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "name", b"name", "resource_info", b"resource_info", "uid", b"uid"]) -> None: ...

global___BoundObjectReference = BoundObjectReference

@typing_extensions.final
class TokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___TokenRequestSpec: ...
    @property
    def status(self) -> global___TokenRequestStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___TokenRequestSpec | None = ...,
        status: global___TokenRequestStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___TokenRequest = TokenRequest

@typing_extensions.final
class TokenRequestSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCES_FIELD_NUMBER: builtins.int
    BOUND_OBJECT_REF_FIELD_NUMBER: builtins.int
    EXPIRATION_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def bound_object_ref(self) -> global___BoundObjectReference: ...
    expiration_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        bound_object_ref: global___BoundObjectReference | None = ...,
        expiration_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bound_object_ref", b"bound_object_ref", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audiences", b"audiences", "bound_object_ref", b"bound_object_ref", "expiration_seconds", b"expiration_seconds", "resource_info", b"resource_info"]) -> None: ...

global___TokenRequestSpec = TokenRequestSpec

@typing_extensions.final
class TokenRequestStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def expiration_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    token: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        expiration_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        token: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration_timestamp", b"expiration_timestamp", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_timestamp", b"expiration_timestamp", "resource_info", b"resource_info", "token", b"token"]) -> None: ...

global___TokenRequestStatus = TokenRequestStatus

@typing_extensions.final
class TokenReview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___TokenReviewSpec: ...
    @property
    def status(self) -> global___TokenReviewStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___TokenReviewSpec | None = ...,
        status: global___TokenReviewStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___TokenReview = TokenReview

@typing_extensions.final
class TokenReviewSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCES_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    token: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        token: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audiences", b"audiences", "resource_info", b"resource_info", "token", b"token"]) -> None: ...

global___TokenReviewSpec = TokenReviewSpec

@typing_extensions.final
class TokenReviewStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCES_FIELD_NUMBER: builtins.int
    AUTHENTICATED_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def audiences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    authenticated: builtins.bool
    error: builtins.str
    @property
    def user(self) -> global___UserInfo: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        audiences: collections.abc.Iterable[builtins.str] | None = ...,
        authenticated: builtins.bool = ...,
        error: builtins.str = ...,
        user: global___UserInfo | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audiences", b"audiences", "authenticated", b"authenticated", "error", b"error", "resource_info", b"resource_info", "user", b"user"]) -> None: ...

global___TokenReviewStatus = TokenReviewStatus

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    EXTRA_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    uid: builtins.str
    username: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        uid: builtins.str = ...,
        username: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra", b"extra", "groups", b"groups", "resource_info", b"resource_info", "uid", b"uid", "username", b"username"]) -> None: ...

global___UserInfo = UserInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloudfront.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_cloudfront.proto\x12\x1aoak9.tython.aws.cloudfront\x1a\x13shared/shared.proto\"}\n\x18\x43\x61\x63hePolicyCookiesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63ookie_behavior\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookies\x18\x03 \x03(\t\"}\n\x18\x43\x61\x63hePolicyHeadersConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fheader_behavior\x18\x02 \x01(\t\x12\x0f\n\x07headers\x18\x03 \x03(\t\"\x8e\x01\n\x1d\x43\x61\x63hePolicyQueryStringsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15query_string_behavior\x18\x02 \x01(\t\x12\x15\n\rquery_strings\x18\x03 \x03(\t\"\x88\x03\n3CachePolicyParametersInCacheKeyAndForwardedToOrigin\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\x0e\x63ookies_config\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.cloudfront.CachePolicyCookiesConfig\x12#\n\x1b\x65nable_accept_encoding_gzip\x18\x03 \x01(\x08\x12L\n\x0eheaders_config\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.cloudfront.CachePolicyHeadersConfig\x12W\n\x14query_strings_config\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.cloudfront.CachePolicyQueryStringsConfig\"\xb8\x02\n\x1c\x43\x61\x63hePolicyCachePolicyConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\x01\x12\x0f\n\x07max_ttl\x18\x04 \x01(\x01\x12\x0f\n\x07min_ttl\x18\x05 \x01(\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x88\x01\n/parameters_in_cache_key_and_forwarded_to_origin\x18\x07 \x01(\x0b\x32O.oak9.tython.aws.cloudfront.CachePolicyParametersInCacheKeyAndForwardedToOrigin\"\x9d\x01\n\x0b\x43\x61\x63hePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x13\x63\x61\x63he_policy_config\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.cloudfront.CachePolicyCachePolicyConfig\"\xfa\x02\n\nCloudFront\x12=\n\x0c\x63\x61\x63he_policy\x18\x01 \x03(\x0b\x32\'.oak9.tython.aws.cloudfront.CachePolicy\x12>\n\x0c\x64istribution\x18\x02 \x01(\x0b\x32(.oak9.tython.aws.cloudfront.Distribution\x12N\n\x15origin_request_policy\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.cloudfront.OriginRequestPolicy\x12J\n\x13realtime_log_config\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.cloudfront.RealtimeLogConfig\x12Q\n\x16streaming_distribution\x18\x05 \x01(\x0b\x32\x31.oak9.tython.aws.cloudfront.StreamingDistribution\"\x8e\x01\nBCloudFrontOriginAccessIdentityCloudFrontOriginAccessIdentityConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"\xed\x01\n\x1e\x43loudFrontOriginAccessIdentity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x91\x01\n)cloud_front_origin_access_identity_config\x18\x02 \x01(\x0b\x32^.oak9.tython.aws.cloudfront.CloudFrontOriginAccessIdentityCloudFrontOriginAccessIdentityConfig\"\x87\x01\n\x13\x44istributionLogging\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0finclude_cookies\x18\x02 \x01(\x08\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0e\n\x06prefix\x18\x04 \x01(\t\"\x84\x01\n\x1e\x44istributionOriginCustomHeader\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x13\n\x0bheader_name\x18\x03 \x01(\t\"u\n\x1a\x44istributionS3OriginConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16origin_access_identity\x18\x02 \x01(\t\"\xfe\x01\n\x1e\x44istributionCustomOriginConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13origin_read_timeout\x18\x02 \x01(\x05\x12\x13\n\x0bhttp_s_port\x18\x03 \x01(\x05\x12 \n\x18origin_keepalive_timeout\x18\x04 \x01(\x05\x12\x1c\n\x14origin_ssl_protocols\x18\x05 \x03(\t\x12\x11\n\thttp_port\x18\x06 \x01(\x05\x12\x1e\n\x16origin_protocol_policy\x18\x07 \x01(\t\"\xb4\x04\n\x12\x44istributionOrigin\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x63onnection_timeout\x18\x02 \x01(\x05\x12Y\n\x15origin_custom_headers\x18\x03 \x03(\x0b\x32:.oak9.tython.aws.cloudfront.DistributionOriginCustomHeader\x12\x1b\n\x13\x63onnection_attempts\x18\x04 \x01(\x05\x12\x13\n\x0b\x64omain_name\x18\x05 \x01(\t\x12P\n\x10s3_origin_config\x18\x06 \x01(\x0b\x32\x36.oak9.tython.aws.cloudfront.DistributionS3OriginConfig\x12\x13\n\x0borigin_path\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12X\n\x14\x63ustom_origin_config\x18\t \x01(\x0b\x32:.oak9.tython.aws.cloudfront.DistributionCustomOriginConfig\x12W\n\x13\x64istribution_config\x18\n \x01(\x0b\x32:.oak9.tython.aws.cloudfront.DistributionDistributionConfig\x12\x16\n\x0e\x63ustom_headers\x18\x0b \x01(\t\"\xf8\x01\n\x1d\x44istributionViewerCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12iam_certificate_id\x18\x02 \x01(\t\x12\x1a\n\x12ssl_support_method\x18\x03 \x01(\t\x12 \n\x18minimum_protocol_version\x18\x04 \x01(\t\x12\'\n\x1f\x63loud_front_default_certificate\x18\x05 \x01(\x08\x12\x1b\n\x13\x61\x63m_certificate_arn\x18\x06 \x01(\t\"\xa7\x01\n%DistributionLambdaFunctionAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cinclude_body\x18\x02 \x01(\x08\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\x1b\n\x13lambda_function_arn\x18\x04 \x01(\t\"z\n\x13\x44istributionCookies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11whitelisted_names\x18\x02 \x03(\t\x12\x0f\n\x07\x66orward\x18\x03 \x01(\t\"\xe0\x01\n\x1b\x44istributionForwardedValues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x07\x63ookies\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.cloudfront.DistributionCookies\x12\x0f\n\x07headers\x18\x03 \x03(\t\x12\x14\n\x0cquery_string\x18\x04 \x01(\x08\x12\x1f\n\x17query_string_cache_keys\x18\x05 \x03(\t\"\xfd\x04\n DistributionDefaultCacheBehavior\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63ompress\x18\x02 \x01(\x08\x12g\n\x1clambda_function_associations\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.cloudfront.DistributionLambdaFunctionAssociation\x12\x18\n\x10target_origin_id\x18\x04 \x01(\t\x12\x1e\n\x16viewer_protocol_policy\x18\x05 \x01(\t\x12\x1f\n\x17realtime_log_config_arn\x18\x06 \x01(\t\x12\x17\n\x0ftrusted_signers\x18\x07 \x03(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x08 \x01(\x01\x12!\n\x19\x66ield_level_encryption_id\x18\t \x01(\t\x12\x17\n\x0f\x61llowed_methods\x18\n \x03(\t\x12\x16\n\x0e\x63\x61\x63hed_methods\x18\x0b \x03(\t\x12\x18\n\x10smooth_streaming\x18\x0c \x01(\x08\x12Q\n\x10\x66orwarded_values\x18\r \x01(\x0b\x32\x37.oak9.tython.aws.cloudfront.DistributionForwardedValues\x12 \n\x18origin_request_policy_id\x18\x0e \x01(\t\x12\x0f\n\x07min_ttl\x18\x0f \x01(\x01\x12\x17\n\x0f\x63\x61\x63he_policy_id\x18\x10 \x01(\t\x12\x0f\n\x07max_ttl\x18\x11 \x01(\x01\"\xc0\x01\n\x1f\x44istributionCustomErrorResponse\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresponse_code\x18\x02 \x01(\x05\x12\x1d\n\x15\x65rror_caching_min_ttl\x18\x03 \x01(\x01\x12\x12\n\nerror_code\x18\x04 \x01(\x05\x12\x1a\n\x12response_page_path\x18\x05 \x01(\t\"s\n\x17\x44istributionStatusCodes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\r\n\x05items\x18\x03 \x03(\x05\"\xad\x01\n\'DistributionOriginGroupFailoverCriteria\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x0cstatus_codes\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.cloudfront.DistributionStatusCodes\"k\n\x1d\x44istributionOriginGroupMember\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\torigin_id\x18\x02 \x01(\t\"\xb5\x01\n\x1e\x44istributionOriginGroupMembers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12H\n\x05items\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.cloudfront.DistributionOriginGroupMember\"\x8b\x02\n\x17\x44istributionOriginGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12^\n\x11\x66\x61ilover_criteria\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.cloudfront.DistributionOriginGroupFailoverCriteria\x12K\n\x07members\x18\x04 \x01(\x0b\x32:.oak9.tython.aws.cloudfront.DistributionOriginGroupMembers\"\xa9\x01\n\x18\x44istributionOriginGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08quantity\x18\x02 \x01(\x05\x12\x42\n\x05items\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.cloudfront.DistributionOriginGroup\"\x82\x01\n\x1a\x44istributionGeoRestriction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tlocations\x18\x02 \x03(\t\x12\x18\n\x10restriction_type\x18\x03 \x01(\t\"\xa4\x01\n\x18\x44istributionRestrictions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x0fgeo_restriction\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.cloudfront.DistributionGeoRestriction\"\x8c\x05\n\x19\x44istributionCacheBehavior\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63ompress\x18\x02 \x01(\x08\x12g\n\x1clambda_function_associations\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.cloudfront.DistributionLambdaFunctionAssociation\x12\x18\n\x10target_origin_id\x18\x04 \x01(\t\x12\x1e\n\x16viewer_protocol_policy\x18\x05 \x01(\t\x12\x1f\n\x17realtime_log_config_arn\x18\x06 \x01(\t\x12\x17\n\x0ftrusted_signers\x18\x07 \x03(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x08 \x01(\x01\x12!\n\x19\x66ield_level_encryption_id\x18\t \x01(\t\x12\x17\n\x0f\x61llowed_methods\x18\n \x03(\t\x12\x14\n\x0cpath_pattern\x18\x0b \x01(\t\x12\x16\n\x0e\x63\x61\x63hed_methods\x18\x0c \x03(\t\x12\x18\n\x10smooth_streaming\x18\r \x01(\x08\x12Q\n\x10\x66orwarded_values\x18\x0e \x01(\x0b\x32\x37.oak9.tython.aws.cloudfront.DistributionForwardedValues\x12 \n\x18origin_request_policy_id\x18\x0f \x01(\t\x12\x0f\n\x07min_ttl\x18\x10 \x01(\x01\x12\x17\n\x0f\x63\x61\x63he_policy_id\x18\x11 \x01(\t\x12\x0f\n\x07max_ttl\x18\x12 \x01(\x01\"\xff\x06\n\x1e\x44istributionDistributionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x07logging\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.cloudfront.DistributionLogging\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x1b\n\x13\x64\x65\x66\x61ult_root_object\x18\x04 \x01(\t\x12?\n\x07origins\x18\x05 \x03(\x0b\x32..oak9.tython.aws.cloudfront.DistributionOrigin\x12U\n\x12viewer_certificate\x18\x06 \x01(\x0b\x32\x39.oak9.tython.aws.cloudfront.DistributionViewerCertificate\x12\x13\n\x0bprice_class\x18\x07 \x01(\t\x12\\\n\x16\x64\x65\x66\x61ult_cache_behavior\x18\x08 \x01(\x0b\x32<.oak9.tython.aws.cloudfront.DistributionDefaultCacheBehavior\x12[\n\x16\x63ustom_error_responses\x18\t \x03(\x0b\x32;.oak9.tython.aws.cloudfront.DistributionCustomErrorResponse\x12K\n\rorigin_groups\x18\n \x01(\x0b\x32\x34.oak9.tython.aws.cloudfront.DistributionOriginGroups\x12\x0f\n\x07\x65nabled\x18\x0b \x01(\x08\x12\x0f\n\x07\x61liases\x18\x0c \x03(\t\x12\x15\n\rip_v6_enabled\x18\r \x01(\x08\x12\x14\n\x0cweb_a_c_l_id\x18\x0e \x01(\t\x12\x14\n\x0chttp_version\x18\x0f \x01(\t\x12J\n\x0crestrictions\x18\x10 \x01(\x0b\x32\x34.oak9.tython.aws.cloudfront.DistributionRestrictions\x12N\n\x0f\x63\x61\x63he_behaviors\x18\x11 \x03(\x0b\x32\x35.oak9.tython.aws.cloudfront.DistributionCacheBehavior\"\x8f\x02\n\x0c\x44istribution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x13\x64istribution_config\x18\x02 \x01(\x0b\x32:.oak9.tython.aws.cloudfront.DistributionDistributionConfig\x12@\n\x04tags\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.cloudfront.Distribution.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n OriginRequestPolicyCookiesConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63ookie_behavior\x18\x02 \x01(\t\x12\x0f\n\x07\x63ookies\x18\x03 \x03(\t\"\x85\x01\n OriginRequestPolicyHeadersConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fheader_behavior\x18\x02 \x01(\t\x12\x0f\n\x07headers\x18\x03 \x03(\t\"\x96\x01\n%OriginRequestPolicyQueryStringsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15query_string_behavior\x18\x02 \x01(\t\x12\x15\n\rquery_strings\x18\x03 \x03(\t\"\x93\x03\n,OriginRequestPolicyOriginRequestPolicyConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12T\n\x0e\x63ookies_config\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.cloudfront.OriginRequestPolicyCookiesConfig\x12T\n\x0eheaders_config\x18\x04 \x01(\x0b\x32<.oak9.tython.aws.cloudfront.OriginRequestPolicyHeadersConfig\x12\x0c\n\x04name\x18\x05 \x01(\t\x12_\n\x14query_strings_config\x18\x06 \x01(\x0b\x32\x41.oak9.tython.aws.cloudfront.OriginRequestPolicyQueryStringsConfig\"\xbe\x01\n\x13OriginRequestPolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12n\n\x1corigin_request_policy_config\x18\x02 \x01(\x0b\x32H.oak9.tython.aws.cloudfront.OriginRequestPolicyOriginRequestPolicyConfig\"\x85\x01\n$RealtimeLogConfigKinesisStreamConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\t\"\xca\x01\n\x19RealtimeLogConfigEndPoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x15kinesis_stream_config\x18\x02 \x01(\x0b\x32@.oak9.tython.aws.cloudfront.RealtimeLogConfigKinesisStreamConfig\x12\x13\n\x0bstream_type\x18\x03 \x01(\t\"\xcc\x01\n\x11RealtimeLogConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\nend_points\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.cloudfront.RealtimeLogConfigEndPoint\x12\x0e\n\x06\x66ields\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x15\n\rsampling_rate\x18\x05 \x01(\x01\"\x88\x01\n\x1cStreamingDistributionLogging\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x0e\n\x06prefix\x18\x04 \x01(\t\"\x8d\x01\n\x1dStreamingDistributionS3Origin\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\x1e\n\x16origin_access_identity\x18\x03 \x01(\t\"\x8c\x01\n#StreamingDistributionTrustedSigners\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x1b\n\x13\x61ws_account_numbers\x18\x03 \x03(\t\"\xa6\x03\n0StreamingDistributionStreamingDistributionConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x07logging\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.cloudfront.StreamingDistributionLogging\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x13\n\x0bprice_class\x18\x04 \x01(\t\x12L\n\ts3_origin\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.cloudfront.StreamingDistributionS3Origin\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x0f\n\x07\x61liases\x18\x07 \x03(\t\x12X\n\x0ftrusted_signers\x18\x08 \x01(\x0b\x32?.oak9.tython.aws.cloudfront.StreamingDistributionTrustedSigners\"\xbd\x02\n\x15StreamingDistribution\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\x1dstreaming_distribution_config\x18\x02 \x01(\x0b\x32L.oak9.tython.aws.cloudfront.StreamingDistributionStreamingDistributionConfig\x12I\n\x04tags\x18\x03 \x03(\x0b\x32;.oak9.tython.aws.cloudfront.StreamingDistribution.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloudfront_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISTRIBUTION_TAGSENTRY._options = None
  _DISTRIBUTION_TAGSENTRY._serialized_options = b'8\001'
  _STREAMINGDISTRIBUTION_TAGSENTRY._options = None
  _STREAMINGDISTRIBUTION_TAGSENTRY._serialized_options = b'8\001'
  _CACHEPOLICYCOOKIESCONFIG._serialized_start=77
  _CACHEPOLICYCOOKIESCONFIG._serialized_end=202
  _CACHEPOLICYHEADERSCONFIG._serialized_start=204
  _CACHEPOLICYHEADERSCONFIG._serialized_end=329
  _CACHEPOLICYQUERYSTRINGSCONFIG._serialized_start=332
  _CACHEPOLICYQUERYSTRINGSCONFIG._serialized_end=474
  _CACHEPOLICYPARAMETERSINCACHEKEYANDFORWARDEDTOORIGIN._serialized_start=477
  _CACHEPOLICYPARAMETERSINCACHEKEYANDFORWARDEDTOORIGIN._serialized_end=869
  _CACHEPOLICYCACHEPOLICYCONFIG._serialized_start=872
  _CACHEPOLICYCACHEPOLICYCONFIG._serialized_end=1184
  _CACHEPOLICY._serialized_start=1187
  _CACHEPOLICY._serialized_end=1344
  _CLOUDFRONT._serialized_start=1347
  _CLOUDFRONT._serialized_end=1725
  _CLOUDFRONTORIGINACCESSIDENTITYCLOUDFRONTORIGINACCESSIDENTITYCONFIG._serialized_start=1728
  _CLOUDFRONTORIGINACCESSIDENTITYCLOUDFRONTORIGINACCESSIDENTITYCONFIG._serialized_end=1870
  _CLOUDFRONTORIGINACCESSIDENTITY._serialized_start=1873
  _CLOUDFRONTORIGINACCESSIDENTITY._serialized_end=2110
  _DISTRIBUTIONLOGGING._serialized_start=2113
  _DISTRIBUTIONLOGGING._serialized_end=2248
  _DISTRIBUTIONORIGINCUSTOMHEADER._serialized_start=2251
  _DISTRIBUTIONORIGINCUSTOMHEADER._serialized_end=2383
  _DISTRIBUTIONS3ORIGINCONFIG._serialized_start=2385
  _DISTRIBUTIONS3ORIGINCONFIG._serialized_end=2502
  _DISTRIBUTIONCUSTOMORIGINCONFIG._serialized_start=2505
  _DISTRIBUTIONCUSTOMORIGINCONFIG._serialized_end=2759
  _DISTRIBUTIONORIGIN._serialized_start=2762
  _DISTRIBUTIONORIGIN._serialized_end=3326
  _DISTRIBUTIONVIEWERCERTIFICATE._serialized_start=3329
  _DISTRIBUTIONVIEWERCERTIFICATE._serialized_end=3577
  _DISTRIBUTIONLAMBDAFUNCTIONASSOCIATION._serialized_start=3580
  _DISTRIBUTIONLAMBDAFUNCTIONASSOCIATION._serialized_end=3747
  _DISTRIBUTIONCOOKIES._serialized_start=3749
  _DISTRIBUTIONCOOKIES._serialized_end=3871
  _DISTRIBUTIONFORWARDEDVALUES._serialized_start=3874
  _DISTRIBUTIONFORWARDEDVALUES._serialized_end=4098
  _DISTRIBUTIONDEFAULTCACHEBEHAVIOR._serialized_start=4101
  _DISTRIBUTIONDEFAULTCACHEBEHAVIOR._serialized_end=4738
  _DISTRIBUTIONCUSTOMERRORRESPONSE._serialized_start=4741
  _DISTRIBUTIONCUSTOMERRORRESPONSE._serialized_end=4933
  _DISTRIBUTIONSTATUSCODES._serialized_start=4935
  _DISTRIBUTIONSTATUSCODES._serialized_end=5050
  _DISTRIBUTIONORIGINGROUPFAILOVERCRITERIA._serialized_start=5053
  _DISTRIBUTIONORIGINGROUPFAILOVERCRITERIA._serialized_end=5226
  _DISTRIBUTIONORIGINGROUPMEMBER._serialized_start=5228
  _DISTRIBUTIONORIGINGROUPMEMBER._serialized_end=5335
  _DISTRIBUTIONORIGINGROUPMEMBERS._serialized_start=5338
  _DISTRIBUTIONORIGINGROUPMEMBERS._serialized_end=5519
  _DISTRIBUTIONORIGINGROUP._serialized_start=5522
  _DISTRIBUTIONORIGINGROUP._serialized_end=5789
  _DISTRIBUTIONORIGINGROUPS._serialized_start=5792
  _DISTRIBUTIONORIGINGROUPS._serialized_end=5961
  _DISTRIBUTIONGEORESTRICTION._serialized_start=5964
  _DISTRIBUTIONGEORESTRICTION._serialized_end=6094
  _DISTRIBUTIONRESTRICTIONS._serialized_start=6097
  _DISTRIBUTIONRESTRICTIONS._serialized_end=6261
  _DISTRIBUTIONCACHEBEHAVIOR._serialized_start=6264
  _DISTRIBUTIONCACHEBEHAVIOR._serialized_end=6916
  _DISTRIBUTIONDISTRIBUTIONCONFIG._serialized_start=6919
  _DISTRIBUTIONDISTRIBUTIONCONFIG._serialized_end=7814
  _DISTRIBUTION._serialized_start=7817
  _DISTRIBUTION._serialized_end=8088
  _DISTRIBUTION_TAGSENTRY._serialized_start=8045
  _DISTRIBUTION_TAGSENTRY._serialized_end=8088
  _ORIGINREQUESTPOLICYCOOKIESCONFIG._serialized_start=8091
  _ORIGINREQUESTPOLICYCOOKIESCONFIG._serialized_end=8224
  _ORIGINREQUESTPOLICYHEADERSCONFIG._serialized_start=8227
  _ORIGINREQUESTPOLICYHEADERSCONFIG._serialized_end=8360
  _ORIGINREQUESTPOLICYQUERYSTRINGSCONFIG._serialized_start=8363
  _ORIGINREQUESTPOLICYQUERYSTRINGSCONFIG._serialized_end=8513
  _ORIGINREQUESTPOLICYORIGINREQUESTPOLICYCONFIG._serialized_start=8516
  _ORIGINREQUESTPOLICYORIGINREQUESTPOLICYCONFIG._serialized_end=8919
  _ORIGINREQUESTPOLICY._serialized_start=8922
  _ORIGINREQUESTPOLICY._serialized_end=9112
  _REALTIMELOGCONFIGKINESISSTREAMCONFIG._serialized_start=9115
  _REALTIMELOGCONFIGKINESISSTREAMCONFIG._serialized_end=9248
  _REALTIMELOGCONFIGENDPOINT._serialized_start=9251
  _REALTIMELOGCONFIGENDPOINT._serialized_end=9453
  _REALTIMELOGCONFIG._serialized_start=9456
  _REALTIMELOGCONFIG._serialized_end=9660
  _STREAMINGDISTRIBUTIONLOGGING._serialized_start=9663
  _STREAMINGDISTRIBUTIONLOGGING._serialized_end=9799
  _STREAMINGDISTRIBUTIONS3ORIGIN._serialized_start=9802
  _STREAMINGDISTRIBUTIONS3ORIGIN._serialized_end=9943
  _STREAMINGDISTRIBUTIONTRUSTEDSIGNERS._serialized_start=9946
  _STREAMINGDISTRIBUTIONTRUSTEDSIGNERS._serialized_end=10086
  _STREAMINGDISTRIBUTIONSTREAMINGDISTRIBUTIONCONFIG._serialized_start=10089
  _STREAMINGDISTRIBUTIONSTREAMINGDISTRIBUTIONCONFIG._serialized_end=10511
  _STREAMINGDISTRIBUTION._serialized_start=10514
  _STREAMINGDISTRIBUTION._serialized_end=10831
  _STREAMINGDISTRIBUTION_TAGSENTRY._serialized_start=8045
  _STREAMINGDISTRIBUTION_TAGSENTRY._serialized_end=8088
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_identity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_identity.proto\x12\x18oak9.tython.gcp.identity\x1a\x13shared/shared.proto\"d\n2IdentityPlatformDefaultSupportedIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x02\n)IdentityPlatformDefaultSupportedIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06idp_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12^\n\x08timeouts\x18\x08 \x01(\x0b\x32L.oak9.tython.gcp.identity.IdentityPlatformDefaultSupportedIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n;IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates\x12\x18\n\x10x509_certificate\x18\x01 \x01(\t\"\xdc\x01\n+IdentityPlatformInboundSamlConfigXIdpConfig\x12\x15\n\ridp_entity_id\x18\x01 \x01(\t\x12\x14\n\x0csign_request\x18\x02 \x01(\x08\x12\x0f\n\x07sso_url\x18\x03 \x01(\t\x12o\n\x10idp_certificates\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates\"\x82\x02\n*IdentityPlatformInboundSamlConfigXSpConfig\x12\x14\n\x0c\x63\x61llback_uri\x18\x01 \x01(\t\x12q\n\x0fsp_certificates\x18\x02 \x03(\x0b\x32X.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXSpConfig.SpCertificatesEntry\x12\x14\n\x0csp_entity_id\x18\x03 \x01(\t\x1a\x35\n\x13SpCertificatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n*IdentityPlatformInboundSamlConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x03\n!IdentityPlatformInboundSamlConfig\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12Y\n\nidp_config\x18\x06 \x01(\x0b\x32\x45.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXIdpConfig\x12W\n\tsp_config\x18\x07 \x01(\x0b\x32\x44.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXSpConfig\x12V\n\x08timeouts\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.identity.IdentityPlatformInboundSamlConfigXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Y\n\'IdentityPlatformOauthIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xba\x02\n\x1eIdentityPlatformOauthIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12S\n\x08timeouts\x18\t \x01(\x0b\x32\x41.oak9.tython.gcp.identity.IdentityPlatformOauthIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"Q\n\x1fIdentityPlatformTenantXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb6\x02\n\x16IdentityPlatformTenant\x12\x1d\n\x15\x61llow_password_signup\x18\x01 \x01(\x08\x12\x14\n\x0c\x64isable_auth\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12 \n\x18\x65nable_email_link_signin\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12K\n\x08timeouts\x18\x08 \x01(\x0b\x32\x39.oak9.tython.gcp.identity.IdentityPlatformTenantXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n8IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x02\n/IdentityPlatformTenantDefaultSupportedIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0e\n\x06idp_id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06tenant\x18\x08 \x01(\t\x12\x64\n\x08timeouts\x18\t \x01(\x0b\x32R.oak9.tython.gcp.identity.IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\nAIdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates\x12\x18\n\x10x509_certificate\x18\x01 \x01(\t\"\xe8\x01\n1IdentityPlatformTenantInboundSamlConfigXIdpConfig\x12\x15\n\ridp_entity_id\x18\x01 \x01(\t\x12\x14\n\x0csign_request\x18\x02 \x01(\x08\x12\x0f\n\x07sso_url\x18\x03 \x01(\t\x12u\n\x10idp_certificates\x18\x04 \x03(\x0b\x32[.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates\"\x8e\x02\n0IdentityPlatformTenantInboundSamlConfigXSpConfig\x12\x14\n\x0c\x63\x61llback_uri\x18\x01 \x01(\t\x12w\n\x0fsp_certificates\x18\x02 \x03(\x0b\x32^.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXSpConfig.SpCertificatesEntry\x12\x14\n\x0csp_entity_id\x18\x03 \x01(\t\x1a\x35\n\x13SpCertificatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n0IdentityPlatformTenantInboundSamlConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x03\n\'IdentityPlatformTenantInboundSamlConfig\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06tenant\x18\x06 \x01(\t\x12_\n\nidp_config\x18\x07 \x01(\x0b\x32K.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXIdpConfig\x12]\n\tsp_config\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXSpConfig\x12\\\n\x08timeouts\x18\t \x01(\x0b\x32J.oak9.tython.gcp.identity.IdentityPlatformTenantInboundSamlConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n-IdentityPlatformTenantOauthIdpConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x02\n$IdentityPlatformTenantOauthIdpConfig\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06tenant\x18\t \x01(\t\x12Y\n\x08timeouts\x18\n \x01(\x0b\x32G.oak9.tython.gcp.identity.IdentityPlatformTenantOauthIdpConfigXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_identity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._options = None
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_options = b'8\001'
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._options = None
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_options = b'8\001'
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_start=73
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_end=173
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIG._serialized_start=176
  _IDENTITYPLATFORMDEFAULTSUPPORTEDIDPCONFIG._serialized_end=490
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_start=492
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_end=579
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIG._serialized_start=582
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXIDPCONFIG._serialized_end=802
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG._serialized_start=805
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG._serialized_end=1063
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_start=1010
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_end=1063
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXTIMEOUTS._serialized_start=1065
  _IDENTITYPLATFORMINBOUNDSAMLCONFIGXTIMEOUTS._serialized_end=1157
  _IDENTITYPLATFORMINBOUNDSAMLCONFIG._serialized_start=1160
  _IDENTITYPLATFORMINBOUNDSAMLCONFIG._serialized_end=1602
  _IDENTITYPLATFORMOAUTHIDPCONFIGXTIMEOUTS._serialized_start=1604
  _IDENTITYPLATFORMOAUTHIDPCONFIGXTIMEOUTS._serialized_end=1693
  _IDENTITYPLATFORMOAUTHIDPCONFIG._serialized_start=1696
  _IDENTITYPLATFORMOAUTHIDPCONFIG._serialized_end=2010
  _IDENTITYPLATFORMTENANTXTIMEOUTS._serialized_start=2012
  _IDENTITYPLATFORMTENANTXTIMEOUTS._serialized_end=2093
  _IDENTITYPLATFORMTENANT._serialized_start=2096
  _IDENTITYPLATFORMTENANT._serialized_end=2406
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_start=2408
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIGXTIMEOUTS._serialized_end=2514
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIG._serialized_start=2517
  _IDENTITYPLATFORMTENANTDEFAULTSUPPORTEDIDPCONFIG._serialized_end=2859
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_start=2861
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIGXIDPCERTIFICATES._serialized_end=2954
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIG._serialized_start=2957
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXIDPCONFIG._serialized_end=3189
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG._serialized_start=3192
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG._serialized_end=3462
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_start=1010
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXSPCONFIG_SPCERTIFICATESENTRY._serialized_end=1063
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXTIMEOUTS._serialized_start=3464
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIGXTIMEOUTS._serialized_end=3562
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIG._serialized_start=3565
  _IDENTITYPLATFORMTENANTINBOUNDSAMLCONFIG._serialized_end=4047
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIGXTIMEOUTS._serialized_start=4049
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIGXTIMEOUTS._serialized_end=4144
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIG._serialized_start=4147
  _IDENTITYPLATFORMTENANTOAUTHIDPCONFIG._serialized_end=4489
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TagsTagBindingXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___TagsTagBindingXTimeouts = TagsTagBindingXTimeouts

@typing_extensions.final
class TagsTagBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    parent: builtins.str
    tag_value: builtins.str
    @property
    def timeouts(self) -> global___TagsTagBindingXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        parent: builtins.str = ...,
        tag_value: builtins.str = ...,
        timeouts: global___TagsTagBindingXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "parent", b"parent", "resource_info", b"resource_info", "tag_value", b"tag_value", "timeouts", b"timeouts"]) -> None: ...

global___TagsTagBinding = TagsTagBinding

@typing_extensions.final
class TagsTagKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___TagsTagKeyXTimeouts = TagsTagKeyXTimeouts

@typing_extensions.final
class TagsTagKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACED_NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    namespaced_name: builtins.str
    parent: builtins.str
    short_name: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___TagsTagKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        namespaced_name: builtins.str = ...,
        parent: builtins.str = ...,
        short_name: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___TagsTagKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "id", b"id", "name", b"name", "namespaced_name", b"namespaced_name", "parent", b"parent", "resource_info", b"resource_info", "short_name", b"short_name", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___TagsTagKey = TagsTagKey

@typing_extensions.final
class TagsTagKeyIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___TagsTagKeyIamBindingXCondition = TagsTagKeyIamBindingXCondition

@typing_extensions.final
class TagsTagKeyIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_KEY_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    tag_key: builtins.str
    @property
    def condition(self) -> global___TagsTagKeyIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        tag_key: builtins.str = ...,
        condition: global___TagsTagKeyIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "tag_key", b"tag_key"]) -> None: ...

global___TagsTagKeyIamBinding = TagsTagKeyIamBinding

@typing_extensions.final
class TagsTagKeyIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___TagsTagKeyIamMemberXCondition = TagsTagKeyIamMemberXCondition

@typing_extensions.final
class TagsTagKeyIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_KEY_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    tag_key: builtins.str
    @property
    def condition(self) -> global___TagsTagKeyIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        tag_key: builtins.str = ...,
        condition: global___TagsTagKeyIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "tag_key", b"tag_key"]) -> None: ...

global___TagsTagKeyIamMember = TagsTagKeyIamMember

@typing_extensions.final
class TagsTagKeyIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    TAG_KEY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    tag_key: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        tag_key: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "tag_key", b"tag_key"]) -> None: ...

global___TagsTagKeyIamPolicy = TagsTagKeyIamPolicy

@typing_extensions.final
class TagsTagValueXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___TagsTagValueXTimeouts = TagsTagValueXTimeouts

@typing_extensions.final
class TagsTagValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACED_NAME_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    SHORT_NAME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    namespaced_name: builtins.str
    parent: builtins.str
    short_name: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___TagsTagValueXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        namespaced_name: builtins.str = ...,
        parent: builtins.str = ...,
        short_name: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___TagsTagValueXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "id", b"id", "name", b"name", "namespaced_name", b"namespaced_name", "parent", b"parent", "resource_info", b"resource_info", "short_name", b"short_name", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___TagsTagValue = TagsTagValue

@typing_extensions.final
class TagsTagValueIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___TagsTagValueIamBindingXCondition = TagsTagValueIamBindingXCondition

@typing_extensions.final
class TagsTagValueIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    tag_value: builtins.str
    @property
    def condition(self) -> global___TagsTagValueIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        tag_value: builtins.str = ...,
        condition: global___TagsTagValueIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role", "tag_value", b"tag_value"]) -> None: ...

global___TagsTagValueIamBinding = TagsTagValueIamBinding

@typing_extensions.final
class TagsTagValueIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___TagsTagValueIamMemberXCondition = TagsTagValueIamMemberXCondition

@typing_extensions.final
class TagsTagValueIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    tag_value: builtins.str
    @property
    def condition(self) -> global___TagsTagValueIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        tag_value: builtins.str = ...,
        condition: global___TagsTagValueIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role", "tag_value", b"tag_value"]) -> None: ...

global___TagsTagValueIamMember = TagsTagValueIamMember

@typing_extensions.final
class TagsTagValueIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    tag_value: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        tag_value: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info", "tag_value", b"tag_value"]) -> None: ...

global___TagsTagValueIamPolicy = TagsTagValueIamPolicy
